@@ -109,6 +109,7 @@ from .blosc2_ext import (
     GLOBAL_REGISTERED_CODECS_STOP,
     MAX_BLOCKSIZE,
     MAX_BUFFERSIZE,
+    MAX_DIM,
     MAX_OVERHEAD,
     MAX_TYPESIZE,
     MIN_HEADER_LENGTH,
@@ -137,6 +138,11 @@ MAX_BUFFERSIZE = MAX_BUFFERSIZE
 """
 Maximum buffer size in bytes for a Blosc2 chunk."""
 
+MAX_FAST_PATH_SIZE = 2**30
+"""
+Maximum size in bytes for a fast path evaluation.
+"""
+
 MAX_OVERHEAD = MAX_OVERHEAD
 """
 Maximum overhead during compression (in bytes). This is
@@ -237,6 +243,9 @@ from .ndarray import (
     sort,
     reshape,
     copy,
+    concat,
+    concatenate,
+    expand_dims,
     empty,
     frombuffer,
     fromiter,
@@ -248,7 +257,10 @@ from .ndarray import (
     full,
     save,
     matmul,
+    permute_dims,
     transpose,
+    matrix_transpose,
+    stack,
 )
 
 from .c2array import c2context, C2Array, URLPath
@@ -267,7 +279,6 @@ from .proxy import Proxy, ProxySource, ProxyNDSource, ProxyNDField, SimpleProxy,
 
 from .schunk import SChunk, open
 
-
 # Registry for postfilters
 postfilter_funcs = {}
 """
